==> bidentd_1.0.10.orig.tar.gz: bidentd-1.0.10/progdesc.php <==
<?php
//TITLE=ident daemon for Linux

$title = 'Bisqwit\'s identd';
$progname = 'bidentd';

$k='';foreach(file('/home/bisqwit/src/unixtools/ident/ChangeLog') as $s)$k.=$s;

$text = array(
   '1. Purpose' => "

ident daemon for unix systems, implementing rfc1413 defined behaviour.<br>
&nbsp;<br>
There is also a Debian package available, coordinated by Wesley W. Terpstra.<br>
The package for your architechture can be downloaded from any official Debian mirror.

", '1. Why another identd daemon?' => "

Because there is not one other one which
worked correctly over multiple NATs.
<br>
        The program works like an ident daemon is supposed to work.
        It allows people to query who's connecting in which port.
        Masquerading is supported, and works recursively.
        Works only under Linux, due to the use of /proc filesystem.<br>
        &nbsp;<br>
        My typical case (why I made this):<ul>
        <li> Alpha has the internet connection. It has an ip in internet.</li>
        <li> Beta is masqueraded by Alpha.</li>
        <li> Gamma is masqueraded by Beta.</li>
        <li> Somebody in Gamma starts irc, and the irc server (in internet)
             gets the username of the user in Gamma, correctly.</li>
        </ul>
        All computers in the identd masquerading chain must be
        running bidentd, except the end part, which can be using
        any identd daemon, as long as that one does not care about
        the source ip address.<br>

", '1. Notes' => "

Version 1.0.8 and prior worked only on the 2.2 -series of the Linux kernel,
but 1.0.9 supports 2.4 too. Not tested though.

", '1. Version history' => "

<pre class=smallerpre>".htmlspecialchars($k)."</pre>

", '1. Copying' => "

bidentd has been written by Joel Yliluoma, a.k.a.
<a href=\"http://iki.fi/bisqwit/\">Bisqwit</a>,
and is distributed under the terms of the
<a href=\"http://www.gnu.org/licenses/licenses.html#GPL\">General Public License</a> (GPL).

", '1. Requirements' => "

GNU make is probably required.<br>

", '1. Installation' => "

    <blockquote>
        make install (as root)<br>
        make startup (Follow the instructions)<br>
    </blockquote>

", '1. Uninstallation' => "
   
    <blockquote>
        make uninstall<br>
        Edit /etc/inetd.conf<br>
    </blockquote>

", '1. Updating from possible previous version' => "

    <blockquote>
        make update<br>
    </blockquote>


", '1. Compilation only.' => "
    
    <blockquote>
        make<br>
    </blockquote>

");
include '/WWW/progdesc.php';

==> bidentd_1.1.1.orig.tar.gz: bidentd-1.1.1/progdesc.php <==
<?php
//TITLE=ident daemon for Linux

$title = 'Bisqwit\'s identd';
$progname = 'bidentd';

$k='';foreach(file('/home/bisqwit/src/unixtools/ident/ChangeLog') as $s)$k.=$s;

$text = array(
   '1. Purpose' => "

ident daemon for unix systems, implementing rfc1413 defined behaviour.<br>
&nbsp;<br>
There is also a Debian package available, coordinated by Wesley W. Terpstra.<br>
The package for your architechture can be downloaded from any official Debian mirror.

", '1. Why another identd daemon?' => "

Because there is not one other one which
worked correctly over multiple NATs.
<br>
        The program works like an ident daemon is supposed to work.
        It allows people to query who's connecting in which port.
        Masquerading is supported, and works recursively.
        Works only under Linux, due to the use of /proc filesystem.<br>
        &nbsp;<br>
        My typical case (why I made this):<ul>
        <li> Alpha has the internet connection. It has an ip in internet.</li>
        <li> Beta is masqueraded by Alpha.</li>
        <li> Gamma is masqueraded by Beta.</li>
        <li> Somebody in Gamma starts irc, and the irc server (in internet)
             gets the username of the user in Gamma, correctly.</li>
        </ul>
        All computers in the identd masquerading chain must be
        running bidentd, except the end part, which can be using
        any identd daemon, as long as that one does not care about
        the source ip address.<br>

", '1. Notes' => "

Version 1.0.8 and prior worked only on the 2.2 -series of the Linux kernel,
but 1.0.9 supports 2.4 too.<br>
Since 1.1.0, kernel family 2.6 is supported too.

", '1. Version history' => "

<pre class=smallerpre>".htmlspecialchars($k)."</pre>

", '1. Copying' => "

bidentd has been written by Joel Yliluoma, a.k.a.
<a href=\"http://iki.fi/bisqwit/\">Bisqwit</a>,
and is distributed under the terms of the
<a href=\"http://www.gnu.org/licenses/licenses.html#GPL\">General Public License</a> (GPL).

", '1. Requirements' => "

GNU make is probably required.<br>

", '1. Installation' => "

    <blockquote>
        make install (as root)<br>
        make startup (Follow the instructions)<br>
    </blockquote>

", '1. Uninstallation' => "
   
    <blockquote>
        make uninstall<br>
        Edit /etc/inetd.conf<br>
    </blockquote>

", '1. Updating from possible previous version' => "

    <blockquote>
        make update<br>
    </blockquote>


", '1. Compilation only.' => "
    
    <blockquote>
        make<br>
    </blockquote>

");
include '/WWW/progdesc.php';
